@@ -399,22 +399,28 @@ where
 {
     let op = eva_common::op::Op::new(initial.startup_timeout());
     let eva_dir = initial.eva_dir().to_owned();
-    if let Some(prepare_command) = initial.prepare_command() {
-        let cmd = format!("cd \"{}\" && {}", eva_dir, prepare_command);
-        let t_o = op.timeout()?.as_secs_f64().to_string();
-        let opts = bmart::process::Options::new()
-            .env("EVA_SYSTEM_NAME", initial.system_name())
-            .env("EVA_DIR", initial.eva_dir())
-            .env("EVA_SVC_ID", initial.id())
-            .env("EVA_SVC_DATA_PATH", initial.data_path().unwrap_or_default())
-            .env("EVA_TIMEOUT", t_o.as_str());
-        let res = bmart::process::command("sh", ["-c", &cmd], op.timeout()?, opts).await?;
-        if !res.ok() {
-            return Err(Error::failed(format!(
-                "prepare command failed: {}",
-                res.err.join("\n")
-            )));
+    if initial.is_mode_normal() {
+        if let Some(prepare_command) = initial.prepare_command() {
+            let cmd = format!("cd \"{}\" && {}", eva_dir, prepare_command);
+            let t_o = op.timeout()?.as_secs_f64().to_string();
+            let opts = bmart::process::Options::new()
+                .env("EVA_SYSTEM_NAME", initial.system_name())
+                .env("EVA_DIR", initial.eva_dir())
+                .env("EVA_SVC_ID", initial.id())
+                .env("EVA_SVC_DATA_PATH", initial.data_path().unwrap_or_default())
+                .env("EVA_TIMEOUT", t_o.as_str());
+            let res = bmart::process::command("sh", ["-c", &cmd], op.timeout()?, opts).await?;
+            if !res.ok() {
+                return Err(Error::failed(format!(
+                    "prepare command failed: {}",
+                    res.err.join("\n")
+                )));
+            }
         }
+    } else if !initial.can_rof() {
+        return Err(Error::failed(
+            "the service is started in react-on-fail mode, but rof disabled for the service",
+        ));
     }
     initial
         .extend_config(op.timeout()?, Path::new(&eva_dir))
